==> resolver-qa-2.0.1-beta.0.tgz: package/static/runtime.code.js <==
function tryGetFn(fnGetter) {
  try {
    const fn = fnGetter()
    if (typeof fn !== "function") {
      throw new Error('skiped - fn is not a function')
    } else {
      return fn
    }
  } catch(err) {
    throw new Error('skiped - not found fn')
  }
}

function getFn(cb) {
  let fn
  try {
    fn = tryGetFn(cb)
  } catch (err) {
    fn = function deliverError() {
      throw err
    }
  }
  return fn
}

function resolveFnExcuteResult(excutorWrapper, args, expectValue, done) {
  const { assert, excutor, excutorReturns } = excutorWrapper
 
  let res
  // excutorWrapper mark api error that occured itself in sync or async
  try {
    res = excutor.apply(null, args)
    if (res instanceof Promise) {
      res.then((result) => {
       excutorReturns.push(result)
        try {
          assert(expectValue, result)
          done()
        } catch(e) {
          done(e)
          // 如果是断言层面的报错，我们是不会去收集的
        }
      }).catch((e) => {
       excutorReturns.push(e)
        done(e)
      })
    } else {
      excutorReturns.push(res)
      assert(expectValue, result) // mocha will catch error in sync, we no need to do it.
      done()
    }
  } catch(e) {
    excutorReturns.push(e)
    done(e)
  }
}

function createExcutorWrapperFn (fn, fnId, deps, sort, assert) {
  const wrapperFn = function (args, expectValue, next) {
    wrapperFn.argsList.push(args)
    wrapperFn.expects.push(expectValue)

    if (helper.isDateTreeNode(expectValue)) {
      wrapperFn.expectValues.push(helper.renderType(expectValue))
    } else {
      wrapperFn.expectValues.push(expectValue)
    }

    resolveFnExcuteResult(wrapperFn, args, expectValue, next)
  }
  
  // expose some api to outside
  wrapperFn.sort = sort
  wrapperFn.rawId = fnId
  wrapperFn.argsList = []
  wrapperFn.excutor = fn
  wrapperFn.deps = deps
  wrapperFn.expects = []
  wrapperFn.expectValues = [] // 用户只希望看到实际渲染的值，而不是 AST
  wrapperFn.excutorReturns = []
  wrapperFn.id = `$Wrapper(${fnId})`
  wrapperFn.assert = assert
  return wrapperFn
}

function tryTransfromDeps(deps = [], current) {
  return deps.map(apiName => {
    const apiConfig = apiMark[apiName]
    if (!apiConfig)
      throw new Error(
        'The api name of ' + apiName + ' was not found in apiMark'
      )
    const testRunner = apiConfig.value
    const excutorReturns = testRunner.excutorReturns
    const lastReturn = excutorReturns[excutorReturns.length - 1]
    if (lastReturn instanceof Error) {
      throw new Error(
        `The ${apiName} ocurred an error, but ${current.rawId} depend it`
      )
    }
    return lastReturn
  })
}

// 根据依赖关系筛选测试用例
function shouldExistTaseCase (targetPath, apiQueue) {
  // 先检查它是不是自身
  if (apiQueue.find((api) => targetPath === api.path)) {
    return true
  }

  // 再检查它是不是依赖
  const depsArray = apiQueue.reduce((acc, item) => {
    acc = acc.concat(item.ref.deps)
    return acc
    
  }, [])

  return depsArray.find((dep) => dep === targetPath)
}

==> resolver-qa-2.1.3-beta.0.tgz: package/static/runtime.code.js <==
function tryGetFn(fnGetter) {
  try {
    const fn = fnGetter()
    if (typeof fn !== "function") {
      throw new Error('skiped - fn is not a function')
    } else {
      return fn
    }
  } catch (err) {
    throw new Error('skiped - not found fn')
  }
}

function getFn(cb) {
  let fn
  try {
    fn = tryGetFn(cb)
  } catch (err) {
    fn = function deliverError() {
      throw err
    }
  }
  return fn
}

function resolveFnExcuteResult(excutorWrapper, args, expectValue, done) {
  const { assert, excutor, excutorReturns } = excutorWrapper

  let res
  // excutorWrapper mark api error that occured itself in sync or async
  try {
    res = excutor.apply(null, args)
    if (res instanceof Promise) {
      res
        .then((res) => {
          excutorReturns.push(res)
          try {
            assert(expectValue, res)
            done(null, res)
          } catch (e) {
            done(e)
            // 如果是断言层面的报错，我们是不会去收集的
          }
        })
        .catch((e) => {
          excutorReturns.push(e)
          done(e)
        })
    } else {
      excutorReturns.push(res)
      assert(expectValue, res) // mocha will catch error in sync, we no need to do it.
      done(null, res)
    }
  } catch (e) {
    excutorReturns.push(res)
    done(e)
  }
}

function createExcutorWrapperFn(fn, fnId, deps, sort, assert) {
  const wrapperFn = function (args, expectValue, next) {
    wrapperFn.argsList.push(args)
    wrapperFn.expects.push(expectValue)

    try {
      if (helper.isDateTreeNode(expectValue)) {
        wrapperFn.expectValues.push(helper.renderType(expectValue))
      } else {
        wrapperFn.expectValues.push(expectValue)
      }
    } catch (err) {
      wrapperFn.expectValues.push(expectValue)
    }

    resolveFnExcuteResult(wrapperFn, args, expectValue, next)
  }

  // expose some api to outside
  wrapperFn.sort = sort
  wrapperFn.rawId = fnId
  wrapperFn.argsList = []
  wrapperFn.excutor = fn
  wrapperFn.deps = deps
  wrapperFn.expects = []
  wrapperFn.expectValues = [] // 用户只希望看到实际渲染的值，而不是 AST
  wrapperFn.excutorReturns = []
  wrapperFn.id = `$Wrapper(${fnId})`
  wrapperFn.assert = assert
  return wrapperFn
}

function tryTransfromDeps(deps = [], current) {
  return deps.map(apiName => {
    const apiConfig = apiMark[apiName]
    if (!apiConfig)
      throw new Error(
        'The api name of ' + apiName + ' was not found in apiMark'
      )
    const testRunner = apiConfig.value
    const excutorReturns = testRunner.excutorReturns
    const lastReturn = excutorReturns[excutorReturns.length - 1]
    if (lastReturn instanceof Error) {
      throw new Error(
        `The '${apiName}' ocurred an error, but '${current.rawId}' depend it`
      )
    }
    return lastReturn
  })
}

// 根据依赖关系筛选测试用例
function shouldExistTaseCase(targetPath, apiQueue) {
  // 先检查它是不是自身
  if (apiQueue.find((api) => targetPath === api.path)) {
    return true
  }

  // 再检查它是不是依赖
  const depsArray = apiQueue.reduce((acc, item) => {
    acc = acc.concat(item.ref.deps)
    return acc

  }, [])

  return depsArray.find((dep) => dep === targetPath)
}
